/**
 * A simple class to provide a autocompling text view. Like that used 
 *	in many Web Browsers.
 * @Author <a href="mailto:mlk@grex.org">Michael Lloyd Lee</a>
 * @extends BTextView
 * See AutoTextView.h for more details.
 *
 * ChangeLog
 * -- Mon Feb  5 00:37:29 GMT 2001
 *  Undrunked Coding Frenzy. 
 *  Work started on the code. Constuctors added, destuctor added.
 *  AddWord Added.
 **/

#include "AutoTextView.h"

#include <stdio.h>
#include <String.h>
#include <List.h>

AutoTextView::AutoTextView(BRect frame, const char *name, 
	BRect textRect, uint32 resizingMode, uint32 flags) 
		: BTextView(frame, name, textRect, resizingMode, flags)
{
	SetUp();
}

AutoTextView::AutoTextView(BRect frame, const char *name, 
	BRect textRect, const BFont *font, const rgb_color *color, uint32 resizingMode, uint32 flags) : BTextView(frame, name, textRect, font, color, resizingMode, flags)
{
	SetUp();
}

AutoTextView::AutoTextView(BMessage *archive) : BTextView( archive )
{
	// This one NEEDS changing to cope with archiving!
	SetUp();
}

AutoTextView::~AutoTextView()
{
	void *anItem;
	for ( int32 i = 0; (anItem = words->ItemAt(i)); i++ )
		delete anItem;

	delete words;
}

void 
AutoTextView::InsertText( const char *text, int32 length, int32 offset, 
	const text_run_array *runs)
{
	BString replace = text;
	if((length == 1)&& (TextLength() >= number_of_letters) 
	 		&& (offset == TextLength())) {
		
		BString itext = Text();
		itext << text;
		BString *anItem;
		for ( int32 i = 0; (anItem = (BString*)words->ItemAt(i)); i++ ) {
			if((!caps && (anItem->ICompare(itext, offset+length) == 0)) 
					|| (caps && (anItem->Compare(itext, offset+length) == 0))){

				hl_offset = offset + 1;
				hl = true;
				BString sleepy(anItem->String());
				sleepy.CopyInto(replace, offset, anItem->Length());
				length = replace.Length();
				hl_end = anItem->Length();
				break;
			}
			
		}
	}
	BTextView::InsertText(replace.String(), length, offset, runs);
}

void
AutoTextView::KeyDown(const char *bytes, int32 numBytes)
{
	hl = false;

	BTextView::KeyDown(bytes, numBytes);

	if(hl)
		Select(hl_offset, hl_end);
}


void
AutoTextView::AddWord(BString *word)
{
	words->AddItem((void*)word);
}

void
AutoTextView::MakeCapsSensitive(bool flag)
{
	caps = flag;
}

bool
AutoTextView::IsCapsSensitive()
{
	return caps;
}

void 
AutoTextView::SetNumberOfLetterBeforeAutoComplete(int no)
{
	number_of_letters = no;
}

int
AutoTextView::GetNumberOfLetterBeforeAutoComplete()
{
	return number_of_letters;
}

void
AutoTextView::SetUp(){
	words = new BList(0);
	caps = false;
	number_of_letters = 4;

}
