/**
 * A simple class to provide a autocompling text view. Like that used in many Web Browsers.
 * @Author <a href="mailto:mlk@grex.org">Michael Lloyd Lee</a>
 * @extends BTextView
 *
 * ChangeLog
 * -- Mon Feb  5 00:37:29 GMT 2001
 *  Undrunked Coding Frenzy. 
 *  Work started on the code. Constuctors added, destuctor added.
 *  AddWord Added. The code to make it work added.
 **/
 
#include <TextView.h>

class BList;
class BString;

class AutoTextView : public BTextView
{
	public:
		/**
		 * Constructors.
		 * @see BTextView's Contrutors.
		 **/
		AutoTextView(BRect frame, const char *name, BRect textRect, uint32 resizingMode, uint32 flags);;
		AutoTextView(BRect frame, const char *name, BRect textRect, const BFont *font, const rgb_color *color, uint32 resizingMode, uint32 flags);
		/**
		 * Archiving does not yet work!
		 **/
		AutoTextView(BMessage *archive);
		~AutoTextView();

		/**
		 * Adds a word to the list of know words
		 * @param word The word to add to the list
		 **/
		virtual void AddWord(BString *word);
		/**
		 * Caps sensitive
		 **/
		virtual void MakeCapsSensitive(bool flag = true);
		virtual bool IsCapsSensitive();

		/**
		 * Set the numner of letters before it autocompletes
		 **/
		virtual void SetNumberOfLetterBeforeAutoComplete(int no);
		virtual int GetNumberOfLetterBeforeAutoComplete();
		
		
		virtual void KeyDown(const char *bytes, int32 numBytes);

	protected:
		virtual void InsertText( const char *text, int32 length, int32 offset, const text_run_array *runs);

	private:
		inline void SetUp();
		/**
		 * The list of word to use to auto-complete.
		 **/
		BList *words;
		/**
		 * The numbers of letters before the AutoTextView trys to complete the word
		 **/
		 int number_of_letters;

		/**
		 * Should the text view highlight some text.
		 * if so, the hl_offset and the hl_end state what area should be highlighted
		 **/
		bool hl;
	 	int32 hl_offset, hl_end ; 
		
		bool caps;
};
